<?php
/**
 * @package		AdsManager
 * @copyright	Copyright (C) 2010-2014 Juloa.com. All rights reserved.
 * @license		GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

use Joomla\Utilities\ArrayHelper as JArrayHelper;

JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_adsmanager'.DS.'tables');
jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 1.5
 */
class AdsmanagerControllerCategories extends TController
{
	var $_view = null;
	var $_model = null;
	
	function __construct($config= array()) {
		parent::__construct($config);
	
		// Apply, Save & New
		$this->registerTask('apply', 'save');
		$this->registerTask('save2new', 'save');
	}
	
	function init()
	{
		// Set the default view name from the Request
		$this->_view = $this->getView("admin",'html');

		// Push a model into the view
		$this->_model = $this->getModel("category");
		try {
			$this->_view->setModel( $this->_model, true );
		} catch (Exception $e) {

		}
		
		$confmodel	  = $this->getModel("configuration");
		$this->_view->setModel( $confmodel );
	}
	
	function display($cachable = false, $urlparams = false)
	{
		$this->init();
		$this->_view->setLayout("listcategories");
		$this->_view->display();
	}
	
	function edit()
	{
		$this->init();
		$this->_view->setLayout("editcategory");
		$this->_view->display();
	}
	
	function add()
	{
		$this->init();
		$this->_view->setLayout("editcategory");
		$this->_view->display();
	}
	
	function save()
	{
		$app = JFactory::getApplication();
		
		$this->canAccess();

		$category = JTable::getInstance('category', 'AdsmanagerTable');
        
        $post = JFactory::getApplication()->input->post->getArray();
        if(!isset($post['usergroupsread']) || !is_array($post['usergroupsread'])) {
			$post['usergroupsread'] = array();
		}
		if(!isset($post['usergroupswrite']) || !is_array($post['usergroupswrite'])) {
			$post['usergroupswrite'] = array();
		}
		$post['usergroupsread'] = implode(',', $post['usergroupsread']);
		$post['usergroupswrite'] = implode(',', $post['usergroupswrite']);
		$post['published'] = $post['categoryPublished'];

		// bind it to the table
		if (!$category -> bind($post)) {
			throw new Exception( $category->getError() );
		}
		// store it in the db
		if (!$category -> store()) {
			throw new Exception( $category->getError() );
		}	
		
		$model = $this->getModel("configuration");
		$conf = $model->getConfiguration();
		
        $post = JFactory::getApplication()->input->post->getArray();
        if(!isset($post['usergroupsread']) || !is_array($post['usergroupsread'])) {
			$post['usergroupsread'] = array();
		}
		if(!isset($post['usergroupswrite']) || !is_array($post['usergroupswrite'])) {
			$post['usergroupswrite'] = array();
		}
		$post['usergroupsread'] = implode(',', $post['usergroupsread']);
		$post['usergroupswrite'] = implode(',', $post['usergroupswrite']);
        
		$category->saveContent($post,JFactory::getApplication()->input->files->getArray(),$conf,$this->getModel("adsmanager"));
	
		cleanAdsManagerCache();
	
		// Redirect the user and adjust session state based on the chosen task.
		$task = JFactory::getApplication()->input->getCmd('task');
		$app->enqueueMessage(\JText::_('ADSMANAGER_CATEGORY_SAVED'), 'message');
		switch ($task)
		{
			case 'apply':
				$app->redirect( 'index.php?option=com_adsmanager&c=categories&task=edit&id='.$category->id, 200 );
				break;
		
			case 'save2new':
				$app->redirect( 'index.php?option=com_adsmanager&c=categories&task=add', 200 );
				break;
		
			default:
				$app->redirect( 'index.php?option=com_adsmanager&c=categories', 200 );
			break;
		}
		
	}
	
	function remove()
	{
		$app = JFactory::getApplication();

		$this->canAccess();

		$category = JTable::getInstance('category', 'AdsmanagerTable');
		
		$ids = JFactory::getApplication()->input->get( 'cid', array(0));
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}

		$model = $this->getModel( "configuration");
		$conf = $model->getConfiguration();
		
		$model = $this->getModel( "field");
		$plugins = $model->getPlugins();
		
		foreach($ids as $id){
			$category->deleteContent($id, $conf, $plugins);
		}
		
		cleanAdsManagerCache();
		
		$app->enqueueMessage(\JText::_('ADSMANAGER_CATEGORY_REMOVED'), 'message');
		$app->redirect( 'index.php?option=com_adsmanager&c=categories', 200 );
	}
	
	function unpublish()
	{
		$this->canAccess();
		$this->_changeState();
	}
	
	function publish()
	{
		$this->canAccess();
		$this->_changeState();
	}
	
	function orderdown()
	{
		$this->canAccess();
		$this->_changeOrder(1);
	}
	
	function orderup()
	{
		$this->canAccess();
		$this->_changeOrder(-1);
	}
	
	function _changeOrder($inc)
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		
		$cid = JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );
		
		if ($cid[0]) {
			$id = $cid[0];
			$row = JTable::getInstance('category', 'AdsmanagerTable');
			$row->load( $id );
			$row->move( $inc, "parent = $row->parent" );
		}
		
		cleanAdsManagerCache();

		$app->redirect( 'index.php?option=com_adsmanager&c=categories', 200);
	}
	
	function _changeState()
	{
		$this->canAccess();
		$app = JFactory::getApplication();


		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );

		$cid		= JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );
		$publish	= ( $this->getTask() == 'publish' ? 1 : 0 );

		JArrayHelper::toInteger($cid);

		if (count( $cid ) < 1)
		{
			$action = $publish ? 'publish' : 'unpublish';
			throw new Exception( JText::_( 'Select an item to' .$action, true ) );
		}
		
		$model = $this->getModel( "adsmanager");
		$model->changeState("#__adsmanager_categories","id","published",$publish,$cid);
		
		cleanAdsManagerCache();
		
		$app->redirect( 'index.php?option=com_adsmanager&c=categories', 200 );
	}	
	
	function saveorder()
	{
		$this->canAccess();
		$app = JFactory::getApplication();


		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );
	
		// Initialize variables
		$cid 	= JFactory::getApplication()->input->get('cid', array(0), 'post', 'array');
		JArrayHelper::toInteger($cid, array(0));
		$total		= count( $cid );
		$order 		= JFactory::getApplication()->input->get( 'order', array(0), 'post', 'array' );
		JArrayHelper::toInteger($order, array(0));
	
		$row = JTable::getInstance('category', 'AdsmanagerTable');

		// update ordering values
		for( $i=0; $i < $total; $i++ ) {
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					throw new Exception($db->getErrorMsg() );
				}
			}
		}
	
		cleanAdsManagerCache();
		
		// Check if i'm using an AJAX call, in this case there is no need to redirect
		$format = JFactory::getApplication()->input->get('format','');
		$status="";
		if ($format == 'json')
		{
			echo json_encode($status);
		
			return;
		}
		
		$app->enqueueMessage(\JText::_('ADSMANAGER_ORDERING_SAVED'), 'message');
		$app->redirect( 'index.php?option=com_adsmanager&c=categories', 200 );
	}

	private function canAccess() {
        $app = JFactory::getApplication();

		//check if the user can access the categories
		$user = JFactory::getUser();
		if(!$user->authorise('adsmanager.accesscategory','com_adsmanager')) {
			$app->enqueueMessage(\JText::_('ADSMANAGER_ORDERING_SAVED'), 'error');
			$app->redirect('index.php', 200);
		}

		return true;
	}
}
