<?php
/**
 * @package		AdsManager
 * @copyright	Copyright (C) 2010-2014 Juloa.com. All rights reserved.
 * @license		GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_adsmanager'.DS.'tables');
jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 1.5
 */
class AdsmanagerControllerColumns extends TController
{
	function __construct($config= array()) {
		parent::__construct($config);
	
		// Apply, Save & New
		$this->registerTask('apply', 'save');
		$this->registerTask('save2new', 'save');
	}
	
	function init()
	{
		// Set the default view name from the Request
		$this->_view = $this->getView("admin",'html');

		// Push a model into the view
		$this->_model = $this->getModel( "column");
		try {
			$this->_view->setModel( $this->_model, true );
		} catch(Exception $e) {

		}
	}
	
	function display($cachable = false, $urlparams = false)
	{
		$this->init();

		$fieldmodel = $this->getModel( "field");
		$this->_view->setModel($fieldmodel);
		
		$this->_view->setLayout("columns");
		$this->_view->display();
	}
	
	function edit()
	{
		$this->init();
		
		$categorymodel = $this->getModel( "category");
		$this->_view->setModel($categorymodel);
		
		$this->_view->setLayout("editcolumn");
		$this->_view->display();
	}
	
	function add()
	{
		$this->init();
		
		$categorymodel = $this->getModel( "category");
		$this->_view->setModel($categorymodel);
		
		$this->_view->setLayout("editcolumn");
		$this->_view->display();
	}
	
	function globalsave()
	{
		$this->canAccess();

		$app = JFactory::getApplication();
	
		$model = $this->getModel("Column");
		
		$model->cleanFieldsByColumn();
	
		$columns = $model->getColumns(null,true);
		$input = JFactory::getApplication()->input;
		foreach($columns as $key => $col) {
			$model->setColumn($col->id,
					$input->getString('title_column_'.$col->id),
					$input->getString('listfields_'.$col->id));
		}
	
		$app->enqueueMessage(\JText::_('ADSMANAGER_COLUMNS_UPDATED'), 'message');
		$app->redirect( 'index.php?option=com_adsmanager&c=columns', 200 );
	}
	
	function save()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$column = JTable::getInstance('column', 'AdsmanagerTable');

		// bind it to the table
		$input = JFactory::getApplication()->input;
		if (!$column -> bind($input->post->getArray())) {
			throw new Exception( $column->getError() );
		}
		
		$field_catsid = $input->get("catsid", array(), 'Array');
		$column->catsid = ",".implode(',', $field_catsid).",";
	
		// store it in the db
		if (!$column -> store()) {
			throw new Exception( $column->getError() );
		}	
		
		cleanAdsManagerCache();
		
		// Redirect the user and adjust session state based on the chosen task.
		$task = $input->getCmd('task');
		$app->enqueueMessage(\JText::_('ADSMANAGER_COLUMN_SAVED'), 'message');
		switch ($task)
		{
			case 'apply':
				$app->redirect( 'index.php?option=com_adsmanager&c=columns&task=edit&cid[]='.$column->id, 200);
				break;
		
			case 'save2new':
				$app->redirect( 'index.php?option=com_adsmanager&c=columns&task=add', 200);
				break;
		
			default:
				$app->redirect( 'index.php?option=com_adsmanager&c=columns', 200);
			break;
		}
		
	}
	
	function remove()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		$input = JFactory::getApplication()->input;
		
		$ids = $input->get( 'cid', array(0), 'Array');
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}
		
		$column = JTable::getInstance('column', 'AdsmanagerTable');
			
		foreach($ids as $id) {
			$column->delete($id);
		}	
		
		cleanAdsManagerCache();
		
		$app->enqueueMessage(\JText::_('ADSMANAGER_COLUMN_REMOVED'), 'message');
		$app->redirect( 'index.php?option=com_adsmanager&c=columns', 200);
	}

	private function canAccess() {
		//check if the user can access the layout - list
		$user = JFactory::getUser();
		if(!$user->authorise('adsmanager.accesslayoutlist','com_adsmanager')) {
			throw new Exception( JText::_('JERROR_ALERTNOAUTHOR'));
		}

		return true;
	}
}
