<?php
/**
 * @package		AdsManager
 * @copyright	Copyright (C) 2010-2014 Juloa.com. All rights reserved.
 * @license		GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

use Joomla\Utilities\ArrayHelper as JArrayHelper;
include_once (JPATH_ROOT.'/components/com_adsmanager/helpers/emailtemplates.php');
JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_adsmanager'.DS.'tables');
jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 1.5
 */
class AdsmanagerControllerContents extends TController
{
	function __construct($config= array()) {
		parent::__construct($config);
		
		// Apply, Save & New
		$this->registerTask('apply', 'save');
		$this->registerTask('save2new', 'save');
	}
	
	function init()
	{
		// Set the default view name from the Request
		$this->_view = $this->getView("admin",'html');

		// Push a model into the view
		$this->_model = $this->getModel( "content");
		try {
			$this->_view->setModel( $this->_model, true );
		} catch(Exception $e) {

		}
		
		$uri = JUri::getInstance();
		$baseurl = JURI::base()."../";

		$this->_view->baseurl = $baseurl;
	}
	
	function display($cachable = false, $urlparams = false)
	{
		$this->init();
		
		$confmodel	  = $this->getModel("configuration");
		$catmodel	  = $this->getModel("category");
		$this->_view->setModel( $confmodel );
		$this->_view->setModel( $catmodel );
		
		$this->_view->setLayout("listcontents");
		$this->_view->display();
	}
	
	function edit()
	{
		$this->init();
		$confmodel	  = $this->getModel("configuration");
		$catmodel	  = $this->getModel("category");
		$usermodel	  = $this->getModel("user");
		$fieldmodel	  = $this->getModel("field");

		$this->_view->setModel( $confmodel );
		$this->_view->setModel( $catmodel );
		$this->_view->setModel( $usermodel );
		$this->_view->setModel( $fieldmodel );

		$this->_view->setLayout("editcontent");
		$this->_view->display();
	}
	
	function add()
	{
		$this->init();
		
		$confmodel	  = $this->getModel("configuration");
		$catmodel	  = $this->getModel("category");
		$usermodel	  = $this->getModel("user");
		$fieldmodel	  = $this->getModel("field");
		
		$this->_view->setModel( $confmodel );
		$this->_view->setModel( $catmodel );
		$this->_view->setModel( $usermodel );
		$this->_view->setModel( $fieldmodel );

		$this->_view->setLayout("editcontent");
		$this->_view->display();
	}
	
	function remove()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$content = JTable::getInstance('contents', 'AdsmanagerTable');
		
		$ids = JFactory::getApplication()->input->get( 'cid', array(0));
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}
		
		$model = $this->getModel( "configuration");
		$conf = $model->getConfiguration();
		
		$model = $this->getModel( "field");
		$plugins = $model->getPlugins();
		
		foreach($ids as $id){
			$content->deleteContent($id,$conf,$plugins);
		}
		
		cleanAdsManagerCache();
		
		$app->enqueueMessage(\JText::_('ADSMANAGER_CONTENT_REMOVED'), 'message');
		$app->redirect( 'index.php?option=com_adsmanager&c=contents', 200);
	}
	
	function unpublish()
	{
		$this->canAccess();
		$this->_changeState();
	}
	
	function publish()
	{
		$this->canAccess();
		$model = $this->getModel( "configuration");
		$conf = $model->getConfiguration();
		
		if ($conf->auto_publish == 0)
		{
			if ($conf->send_email_on_validation_to_user == 1) {	
				$cid = JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );		
				foreach($cid as $id) {
					$model = $this->getModel( "content");
					$content = $model->getContent($id,false);
					$usermodel = $this->getModel("user");
					$user = $usermodel->getUser($content->userid);
					EmailTemplateHelperEmail::sendEmail($content, 'adsmanager_content_validated');
					$model->updateContentDate($id);
				}
			}
		}
		
		$this->_changeState();
	}
	
	function duplicate()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		$ids = JFactory::getApplication()->input->get( 'cid', array());
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}
		
		if (count($ids) == 0) {
			$app->redirect( 'index.php?option=com_adsmanager&c=contents', 200);
		}

		$model = $this->getModel( "content");
		
		foreach($ids as $contentid) {
			$model->duplicate($contentid);	
		}
		
		cleanAdsManagerCache();

		$app->enqueueMessage(\JText::_('ADSMANAGER_CONTENT_SAVED'), 'message');
		$app->redirect( 'index.php?option=com_adsmanager&c=contents', 200);
	}
	function save($src=null, $orderingFilter = '', $ignore = '')
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$contentid = JFactory::getApplication()->input->getInt('id', 0);
		
		// New or Update
		if ($contentid != 0)
			$isUpdateMode = 1;
		else
			$isUpdateMode = 0;
		
		$content = JTable::getInstance('contents', 'AdsmanagerTable');
		if ($contentid != 0) {
			$content->load($contentid);
			$previouspublished = $content->published;
		}

		$model = $this->getModel("configuration");
		$conf = $model->getConfiguration();
		
		$model = $this->getModel("field");
		$plugins = $model->getPlugins();
		
		// bind it to the table
		$content->bindContent(JFactory::getApplication()->input->post->getArray(),JFactory::getApplication()->input->files->getArray(),
							  $conf,$this->getModel("adsmanager"),$plugins);
							 	   
		if (function_exists('bindPaidSystemContent')) {
			bindPaidSystemContent($content,
								  JFactory::getApplication()->input->post->getArray(),JFactory::getApplication()->input->files->getArray(),
								  $conf,$this->getModel("adsmanager"));
		}
		
		$errors = $content->getErrors();
		if (count($errors) > 0) {
			throw new Exception( $content->getError() );
		}
	
		$content->saveContent(null);
		
		if (($contentid != 0)&&($conf->auto_publish == 0)) {
			if (($previouspublished == 0)&&(JFactory::getApplication()->input->getInt('published', 1))) {
				$usermodel = $this->getModel("user");
				$user = $usermodel->getUser($content->userid);
				$cmodel = $this->getModel("content");
				EmailTemplateHelperEmail::sendEmail($content, 'adsmanager_content_validated');
				$cmodel->updateContentDate($id);
			}
		}
		
		cleanAdsManagerCache();
		
		$category = JFactory::getApplication()->input->getInt('category', 0);
		
		if ($category != 0) {
			$extra = "&catid=$category";
		} else {
			$extra= "";
		}
		
		$task = JFactory::getApplication()->input->getCmd('task');
		// Redirect the user and adjust session state based on the chosen task.
		$app->enqueueMessage(\JText::_('ADSMANAGER_CONTENT_SAVED'), 'message');
		switch ($task)
		{
			case 'apply':
				$app->redirect( 'index.php?option=com_adsmanager&c=contents&task=edit&id='.$content->id, 200);
				break;
		
			case 'save2new':
				$app->redirect( "index.php?option=com_adsmanager&c=contents{$extra}&task=add", 200);
				break;
		
			default:
				$app->redirect( 'index.php?option=com_adsmanager&c=contents', 200);
				break;
		}
	}
	
	function _changeState()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );

		$cid		= JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );
		$publish	= ( $this->getTask() == 'publish' ? 1 : 0 );

		JArrayHelper::toInteger($cid);

		if (count( $cid ) < 1)
		{
			$action = $publish ? 'publish' : 'unpublish';
			throw new Exception( JText::_( 'Select an item to' .$action, true ) );
		}
		
		$model = $this->getModel( "adsmanager");
		$model->changeState("#__adsmanager_ads","id","published",$publish,$cid);
		
		cleanAdsManagerCache();

		$app->redirect( 'index.php?option=com_adsmanager&c=contents', 200);
	}

	private function canAccess() {
		//check if the user can access the contents
		$user = JFactory::getUser();
		if(!$user->authorise('adsmanager.accesscontent','com_adsmanager')) {
			throw new Exception( JText::_('JERROR_ALERTNOAUTHOR'));
		}

		return true;
	}
}
