<?php
/**
 * @package		AdsManager
 * @copyright	Copyright (C) 2010-2014 Juloa.com. All rights reserved.
 * @license		GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

use Joomla\Utilities\ArrayHelper as JArrayHelper;

JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_adsmanager'.DS.'tables');
jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 1.5
 */
class AdsmanagerControllerFields extends TController
{
	function __construct($config= array()) {
		parent::__construct($config);
	
		// Apply, Save & New
		$this->registerTask('apply', 'save');
		$this->registerTask('save2new', 'save');
	}
	
	function init()
	{
		// Set the default view name from the Request
		$this->_view = $this->getView("admin",'html');

		// Push a model into the view
		$this->_model = $this->getModel( "field");
		try {
			$this->_view->setModel( $this->_model, true );
		} catch (Exception $e) {

		}
	}
	
	function display($cachable = false, $urlparams = false)
	{
		$this->init();
		
		$this->_view->setLayout("listfields");
		$this->_view->display();
	}
	
	function edit()
	{
		$this->init();
		$catmodel		= $this->getModel("category");
		$positionmodel	= $this->getModel("position");
		$columnmodel	= $this->getModel("column");
		$this->_view->setModel( $catmodel );
		$this->_view->setModel( $positionmodel );
		$this->_view->setModel( $columnmodel );
		
		$this->_view->setLayout("editfield");
		$this->_view->display();
	}
	
	function add()
	{
		$this->init();
		$catmodel		= $this->getModel("category");
		$positionmodel	= $this->getModel("position");
		$columnmodel	= $this->getModel("column");
		$this->_view->setModel( $catmodel );
		$this->_view->setModel( $positionmodel );
		$this->_view->setModel( $columnmodel );
		
		$this->_view->setLayout("editfield");
		$this->_view->display();
	}
	
	function save()
	{
		$this->canAccess();
		
		$field = JTable::getInstance('field', 'AdsmanagerTable');

				$post = JFactory::getApplication()->input->post->getArray();
        if (!isset($post['options_common_usergroups_read']))
        	$post['options_common_usergroups_read'] = array();
        $post['options_common_usergroups_read'] = implode(',', $post['options_common_usergroups_read']);
        if (!isset($post['options_common_usergroups_write']))
        	$post['options_common_usergroups_write'] = array();
        $post['options_common_usergroups_write'] = implode(',', $post['options_common_usergroups_write']);
        
        //Prevent strange case with name in UPPERCASE (javascript error that prevent lowercase conversion on 
        // client size
        if (isset($post['name'])) {
        	$post['name'] = strtolower($post['name']);
				}

				//Assign a default falue to catsid and options to avoid a crash - Joomla4
				$post['catsid'] = ',-1,';
				$post['options'] = ',-1,';
				if($post['size'] == '') {
					unset($post['size']);
				}
				if($post['ordering'] == '') {
					unset($post['ordering']);
				}
				if($post['cols'] == '') {
					unset($post['cols']);
				}
				if($post['rows'] == '') {
					unset($post['rows']);
				}
				
        // bind it to the table
		if (!$field -> bind($post)) {
			throw new Exception( $field->getError() );
		}
        
		// store it in the db
		if (!$field -> store()) {
			throw new Exception( $field->getError() );
		}	
		
		$this->_model = $this->getModel( "field");
		$plugins = $this->_model->getPlugins();
		$field->saveContent($post,$plugins);
	
		cleanAdsManagerCache();
	
		// Redirect the user and adjust session state based on the chosen task.
		$task = JFactory::getApplication()->input->getCmd('task');
		$this->app->enqueueMessage(\JText::_('ADSMANAGER_FIELD_SAVED'), 'message');
		switch ($task)
		{
			case 'apply':
				$this->app->redirect( 'index.php?option=com_adsmanager&c=fields&task=edit&cid='.$field->fieldid, 200);
				break;
		
			case 'save2new':
				$this->app->redirect( 'index.php?option=com_adsmanager&c=fields&task=add', 200);
				break;
		
			default:
				$this->app->redirect( 'index.php?option=com_adsmanager&c=fields', 200);
				break;
		}
		
	}
	
	function remove()
	{
		$this->canAccess();
		
		$field = JTable::getInstance('field', 'AdsmanagerTable');
		
		$ids = JFactory::getApplication()->input->get( 'cid', array(0));
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}
		
		$this->_model = $this->getModel( "field");
		$plugins = $this->_model->getPlugins();
		
		foreach($ids as $id){
			$field->deleteContent($id,$plugins);
		}
		
		cleanAdsManagerCache();
		
		$this->app->enqueueMessage(\JText::_('ADSMANAGER_FIELD_REMOVED'), 'message');
		$this->app->redirect( 'index.php?option=com_adsmanager&c=fields', 200);
	}
	
	function unpublish()
	{
		$this->_changeState();
	}
	
	function publish()
	{
		$this->_changeState();
	}
	
	function orderdown()
	{
		$this->_changeOrder(1);
	}
	
	function orderup()
	{
		$this->_changeOrder(-1);
	}
	
	function _changeOrder($inc)
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$cid		= JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );
		
		if ($cid[0]) {
			$id = $cid[0];
			$row = JTable::getInstance('field', 'AdsmanagerTable');
			$row->load( $id );
			$row->move( $inc, "1" );
		}
		
		cleanAdsManagerCache();

		$app->redirect( 'index.php?option=com_adsmanager&c=fields', 200);
	}
	
	function _changeState()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );

		$cid		= JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );
		$publish	= ( $this->getTask() == 'publish' ? 1 : 0 );

		JArrayHelper::toInteger($cid);

		if (count( $cid ) < 1)
		{
			$action = $publish ? 'publish' : 'unpublish';
			throw new Exception( JText::_( 'Select an item to' .$action, true ) );
		}
		
		$model = $this->getModel( "adsmanager");
		$model->changeState("#__adsmanager_fields","fieldid","published",$publish,$cid);
		
		cleanAdsManagerCache();
		
		$app->redirect( 'index.php?option=com_adsmanager&c=fields', 200);
	}	
	
	function saveorder()
	{
		$this->canAccess();

		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );
	
		// Initialize variables
		$cid 	= JFactory::getApplication()->input->get('cid', array(0), 'post', 'array');
		JArrayHelper::toInteger($cid, array(0));
		$total		= count( $cid );
		$order 		= JFactory::getApplication()->input->get( 'order', array(0), 'post', 'array' );
		JArrayHelper::toInteger($order, array(0));
	
		$row = JTable::getInstance('field', 'AdsmanagerTable');

		// update ordering values
		for( $i=0; $i < $total; $i++ ) {
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					throw new Exception( $db->getErrorMsg() );
				}
			}
		}
	
		cleanAdsManagerCache();
		
		// Check if i'm using an AJAX call, in this case there is no need to redirect
		$format = JFactory::getApplication()->input->get('format','');
		$status="";
		if ($format == 'json')
		{
			echo json_encode($status);
		
			return;
		}
		
		$this->app->enqueueMessage(\JText::_('ADSMANAGER_ORDERING_SAVED'), 'message');
		$this->app->redirect( 'index.php?option=com_adsmanager&c=fields', 200);
	}
	
	function required()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		$cid		= JFactory::getApplication()->input->get( 'cid', array(), '', 'array' );
		$required	= JFactory::getApplication()->input->getInt( 'required', 0 );

		JArrayHelper::toInteger($cid);

		if (count( $cid ) < 1)
		{
			$action = $required ? 'required' : 'unrequired';
			throw new Exception( JText::_( 'Select an item to' .$action, true ) );
		}
		
		$model = $this->getModel( "adsmanager");
		$model->changeState("#__adsmanager_fields","fieldid","required",$required,$cid);
		
		cleanAdsManagerCache();
		
		$app->redirect( 'index.php?option=com_adsmanager&c=fields', 200);
	}

	private function canAccess() {
		//check if the user can access the fields
		$user = JFactory::getUser();
		if(!$user->authorise('adsmanager.accessfield','com_adsmanager')) {
			throw new Exception( JText::_('JERROR_ALERTNOAUTHOR'));
		}

		return true;
	}
}
